@@ -28,7 +28,7 @@ my @attributes = qw(
 );
 __PACKAGE__->mk_accessors( @attributes, qw( debug pps ) );
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 sub init {
     my $self = shift;
@@ -64,6 +64,15 @@ sub build_pager {
     return $pager;
 }
 
+sub add_attribute {
+    my $self = shift;
+    for my $attr (@_) {
+        $self->mk_accessors($attr);
+        push @attributes, $attr;
+    }
+}
+
+
 1;
 
 __END__
@@ -176,6 +185,12 @@ Returns the Response in the chosen serialization format.
 
 Response objects are overloaded to call stringify().
 
+=head2 add_attribute( I<attribute_name> )
+
+Adds get/set method I<attribute_name> to the class and will include
+that attribute in as_hash(). This method is intended to make it easier
+to extend the basic structure without needing to subclass.
+
 =head1 AUTHOR
 
 Peter Karman, C<< <karman at cpan.org> >>
